@@ -1,13 +1,31 @@
+#' Convert Markdown headings into a mermaid mindmap
+#'
+#' @param from A vector with Markdown headings
+#' @param root Character. The string displayed as the root (center) of the mind map.
+#' @param mmd_shape Character vector. The shape of mermaid mindmap nodes. See \href{https://bookdown.org/yihui/bookdown/cross-references.html}{{Mermaid document}}.
+#' @returns Mermaid mindmap code chunk
+md2mmd <- function(from, root = 'mindr', mmd_shape = c('cloud', 'rounded_square', 'square', 'bang', 'circle', 'hexagon')) {
+  mmd <- gsub('^(#*)# (.*)$', '\\1  \\2', from)
+  mmd <- gsub('#', '  ', mmd)
+  mmd <- gsub('`', '', mmd)
+  mmd1 <- gsub('^( *)[^ ]*.*$', '\\1', mmd)
+  mmd2 <- gsub('^ *([^ ]*.*)$', '\\1', mmd)
+  leveli <- nchar(mmd1) /  2 + 1
+  leveln <- max(leveli)
+  if (length(mmd_shape) < leveln) mmd_shape <- c(mmd_shape, rep('rounded_square', leveln - length(mmd_shape)))
+  mmd_shape <- mmd_shape[1:leveln]
+  shape_root <- get_mmdshape(mmd_shape[1])
+  for (i in 2:leveln) {
+    shapei <- get_mmdshape(mmd_shape[i])
+    mmd2[leveli == i] <- paste0(shapei[1], '"', mmd2[leveli == i], '"', shapei[2])
+  }
+  out <- paste0(mmd1, 'id', 1:length(mmd), mmd2)
+  c('```{mermaid}',  'mindmap', paste0('  root', shape_root[1], root, shape_root[2]), paste0('  ', out), '```')
+}
+
 #' Extract headings of (R) Markdown-syntax text as an outline
 #' @inheritParams mm
 #' @return Character, showing the outline.
-#' @export
-#' @examples
-#' input <- system.file('examples/mindr-md.Rmd', package = 'mindr')
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' outline(input_txt)
-#' outline(input_txt, md_list = TRUE, md_bookdown = TRUE)
-#' outline(input_txt, md_list = TRUE, md_bookdown = TRUE, md_maxlevel = 2)
 outline <- function(from,
                     md_list = FALSE,
                     md_eq = FALSE,
@@ -22,16 +40,16 @@ outline <- function(from,
 
   # exclude the code blocks
   codeloc4backsticks <- grep('^````', from)
-  if (length(codeloc4backsticks) > 0){
+  if (length(codeloc4backsticks) > 0) {
     from <- from[!sapply(1:mdlength, function(x) rmvcode(index = x, loc = codeloc4backsticks))]
   }
   codeloc3backsticks <- grep('^```', from)
-  if (length(codeloc3backsticks) > 0){
+  if (length(codeloc3backsticks) > 0) {
     from <- from[!sapply(1:mdlength, function(x) rmvcode(index = x, loc = codeloc3backsticks))]
   }
 
   # convert list to heading
-  if (md_list){
+  if (md_list) {
     from <- list2heading(from)
   }
 
@@ -39,7 +57,7 @@ outline <- function(from,
   headingloc <- grep(paste0('^#{1,', md_maxlevel, '} '), from)
 
   # remove the curly brackets
-  if (!md_braces){
+  if (!md_braces) {
     from[headingloc] <- gsub(pattern = '\\{.*\\}', '', from[headingloc])
   }
 
@@ -70,7 +88,7 @@ outline <- function(from,
       heading[lower_loc] <- paste0('#', heading[lower_loc])
     }
   }
-  if (!is.na(eq_loc[1])){
+  if (!is.na(eq_loc[1])) {
     heading <- c(heading, from[eq_loc])[order(c(headingloc, eq_loc))]
   }
   return(heading)
@@ -78,18 +96,7 @@ outline <- function(from,
 
 #' Convert (R) Markdown-syntax text to FreeMind mind map code
 #' @inheritParams mm
-#' @return FreeMind mind map code, which can be saved as a .mm file and viewed by common mind map software, such as \href{http://freemind.sourceforge.net/wiki/index.php/Main_Page}{FreeMind} and \href{https://www.xmind.net}{XMind}.
-#' @export
-#' @examples
-#' input <- system.file('examples/mindr-md.Rmd', package = 'mindr')
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' output_txt <- md2mm(input_txt)
-#' output <- tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".mm")
-#' writeLines(output_txt, output, useBytes = TRUE)
-#' # file.show(input) # Open the input file
-#' # file.show(output) # Open the output file
-#' message('Input:  ', input, '\nOutput: ', output)
-#' # file.remove(output) # remove the output file
+#' @return FreeMind mind map code, which can be saved as a .mm file and viewed by common mind map software, such as \href{https://freemind.sourceforge.io/wiki/index.php/Main_Page}{FreeMind} and \href{https://xmind.com}{XMind}.
 md2mm <- function(from = NA,
                   root = 'mindr',
                   md_list = FALSE,
@@ -110,17 +117,6 @@ md2mm <- function(from = NA,
 #' Convert FreeMind mind map code into Markdown headings
 #' @inheritParams mm
 #' @return Character, showing outline in Markdown syntax.
-#' @export
-#' @examples
-#' input <- system.file('examples/mindr-mm.mm', package = 'mindr')
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' output_txt <- mm2md(input_txt)
-#' output <- tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".md")
-#' writeLines(output_txt, output, useBytes = TRUE)
-#' # file.show(input) # Open the input file
-#' # file.show(output) # Open the output file
-#' message('Input:  ', input, '\nOutput: ', output)
-#' # file.remove(output) # remove the output file
 mm2md <- function(from = NA) {
   # compatible for both versions: node ends with '/>' or '</node>'
   mm <- gsub('/>', '</node>', from)
@@ -156,17 +152,6 @@ mm2md <- function(from = NA) {
 #' @inheritParams mm
 #' @return R markdown-syntax text.
 #' @importFrom knitr spin
-#' @export
-#' @examples
-#' input <- system.file('examples/mindr-r.R', package = 'mindr')
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' output_txt <- r2md(from = input_txt)
-#' output <- tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".Rmd")
-#' writeLines(output_txt, output, useBytes = TRUE)
-#' # file.show(input) # Open the input file
-#' # file.show(output) # Open the output file
-#' message('Input:  ', input, '\nOutput: ', output)
-#' # file.remove(output) # remove the output file
 r2md <- function(from = NA) {
   # process the headings
   ## find the location of the headings
@@ -192,17 +177,6 @@ r2md <- function(from = NA) {
 #' @inheritParams mm
 #' @return Character, R code.
 #' @importFrom knitr purl
-#' @export
-#' @examples
-#' input <- system.file('examples/mindr-md.Rmd', package = 'mindr')
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' output_txt <- md2r(from = input_txt)
-#' output <- tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".R")
-#' writeLines(output_txt, output, useBytes = TRUE)
-#' # file.show(input) # Open the input file
-#' # file.show(output) # Open the output file
-#' message('Input:  ', input, '\nOutput: ', output)
-#' # file.remove(output) # remove the output file
 md2r <- function(from = NA, r_seclabel = ' --------', r_chunkheading = FALSE) {
   # prepare a temp file for knitr::purl()
   rmdfile_temp <- tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".Rmd")
@@ -236,17 +210,6 @@ md2r <- function(from = NA, r_seclabel = ' --------', r_chunkheading = FALSE) {
 #' Display a directory hierarchical structure in Markdown syntax
 #' @inheritParams mm
 #' @return Character, in Markdown syntax.
-#' @export
-#' @examples
-#' input <- system.file(package = 'mindr')
-#' dir2md(input)
-#' dir2md(input, dir_files = FALSE, dir_all = TRUE, dir_excluded = 'Meta')
-#' output_txt <- dir2md(input)
-#' output <- tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".Rmd")
-#' writeLines(output_txt, output, useBytes = TRUE)
-#' message('Input:  ', input, '\nOutput: ', output)
-#' # file.show(output) # Open the output file
-#' # file.remove(output) # remove the output file
 dir2md <- function(from = '.', dir_files = TRUE, dir_all = TRUE, dir_excluded = NA) {
   tree <- if (dir_files) {
     list.files(from, all.files = dir_all, recursive = TRUE, include.dirs = TRUE)
@@ -268,24 +231,7 @@ dir2md <- function(from = '.', dir_files = TRUE, dir_all = TRUE, dir_excluded =
 #' Create hierarchical directories according to (R) Markdown-syntax text
 #' @inheritParams mm
 #' @return Directories generated.
-#' @export
-#' @examples
-#' output <- file.path(tempdir(), 'mindr')
-#' md2dir(c('# a', '## a1', '## a2'), output)
-#' message('Output: ', output)
-#' # unlink(output, recursive = TRUE) # remove the output file
-#'
-#' input <- system.file('examples/mindr-md.Rmd', package = 'mindr')
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' output <- file.path(tempdir(), 'mindr')
-#' md2dir(from = input_txt, output)
-#' message('Input:  ', input, '\nOutput: ', output)
-#' # file.show(input) # Open the input file
-#' # unlink(output, recursive = TRUE) # remove the output file
-#'
-#' md2dir(from = input_txt, output, md_list = TRUE)
-md2dir <- function(from = NA, dir_to = 'mindr', md_list = FALSE, md_bookdown = TRUE, dir_quiet = FALSE){
-  if (is.na(dir_to)) dir_to <- 'mindr'
+md2dir <- function(from = NA, dir_to, md_list = FALSE, md_bookdown = TRUE, dir_quiet = FALSE){
   if (dir.exists(dir_to)) return(warning(dir_to, ' already exists! Please use another folder name for "dir_to =" and try again.'))
   md <- outline(from = from,
                 md_list = md_list,
@@ -302,10 +248,10 @@ md2dir <- function(from = NA, dir_to = 'mindr', md_list = FALSE, md_bookdown = T
   dirs <- character(length = n)
   dirs[1] <- titles[1]
   for (i in 2:n) {
-    if (level_change[i - 1] == 0) dirs[i] <- file.path(dirname(dirs[i-1]), titles[i])
-    if (level_change[i - 1] == 1) dirs[i] <- file.path(dirs[i-1], titles[i])
+    if (level_change[i - 1] == 0) dirs[i] <- file.path(dirname(dirs[i - 1]), titles[i])
+    if (level_change[i - 1] == 1) dirs[i] <- file.path(dirs[i - 1], titles[i])
     if (level_change[i - 1] < 0) {
-      dirs[i] <- dirname(dirs[i-1])
+      dirs[i] <- dirname(dirs[i - 1])
       for (j in 1:abs(level_change[i - 1])) dirs[i] <- dirname(dirs[i])
       dirs[i] <- ifelse(dirs[i] == '.', titles[i], file.path(dirs[i], titles[i]))
     }
@@ -321,38 +267,7 @@ md2dir <- function(from = NA, dir_to = 'mindr', md_list = FALSE, md_bookdown = T
 #' @inheritParams mm
 #' @return HTML widget object.
 #' @importFrom htmlwidgets createWidget sizingPolicy
-#' @export
 #' @details This function, adapted from the \href{https://github.com/seifer08ms/Rmarkmap}{Rmarkup} package, creates a markmap widget using htmlwidgets. The widget can be rendered on HTML pages generated from R Markdown, Shiny,or other applications.
-#' @examples
-#' # Display Markdown:
-#' input <- system.file('examples/mindr-md.Rmd', package = 'mindr')
-#' # file.show(input)
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' markmap(input_txt)
-#' markmap(input_txt, root = basename(input),
-#'         md_list = TRUE, md_eq = FALSE, md_braces = FALSE, md_bookdown = TRUE)
-#'
-#' # Display Mind Map:
-#' input <- system.file('examples/mindr-mm.mm', package = 'mindr')
-#' # file.show(input)
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' markmap(input_txt)
-#' markmap(input_txt, root = basename(input))
-#'
-#' # Display R script:
-#' input <- system.file('examples/mindr-r.R', package = 'mindr')
-#' # file.show(input)
-#' from <- input_txt <- readLines(input, encoding = 'UTF-8')
-#' markmap(input_txt)
-#' markmap(input_txt, root = basename(input),
-#'         md_list = TRUE, md_eq = FALSE, md_braces = FALSE, md_bookdown = TRUE)
-#'
-#' # Display directory:
-#' input <- system.file(package = 'mindr')
-#' markmap(input)
-#' markmap(input, root = 'The mindr package',
-#'         dir_files = FALSE, dir_excluded = c('Meta','htmlwidgets/lib'),
-#'         widget_elementId = "mindr-dir")
 markmap <- function(from = '.', root = NA, input_type = c('auto', 'markdown', 'mindmap', 'R', 'dir'),
                     md_list = FALSE, md_eq = FALSE, md_braces = FALSE, md_bookdown = FALSE, md_maxlevel = '', # markdown options
                     dir_files = TRUE, dir_all = TRUE, dir_excluded = NA, # dir options
@@ -398,7 +313,7 @@ markmap <- function(from = '.', root = NA, input_type = c('auto', 'markdown', 'm
 #'
 #' @details This function is adapted from the \href{https://github.com/seifer08ms/Rmarkmap}{Rmarkup} package.
 #'
-#' Currently, markmap have 'default' and 'colorful' themes. colorful' themes have three different parameters from default themes: {nodeHeight: 10, renderer: 'basic',color: 'category20'}
+#' Currently, markmap have 'default' and 'colorful' themes.
 #' @param preset the name of built-in theme for markmap. If present, any other parameters will be ignored.
 #' @param nodeHeight the height of nodes in the markmap.
 #' @param nodeWidth the width of nodes in the markmap.
@@ -411,16 +326,7 @@ markmap <- function(from = '.', root = NA, input_type = c('auto', 'markdown', 'm
 #' @param renderer rendered shaped of markmap. A character value ,either 'basic' or 'boxed'.
 #' @param ... other options.
 #' @seealso \url{https://github.com/seifer08ms/Rmarkmap} and \url{https://github.com/dundalek/markmap/blob/master/lib/view.mindmap.js} for details.
-#' @export
-#' @examples
-#' input <- system.file('examples/mindr-md.Rmd', package = 'mindr')
-#' # file.show(input)
-#' input_txt <- readLines(input, encoding = 'UTF-8')
-#' markmap(input_txt)
-#' markmap(input_txt, widget_options = markmapOption(preset = 'default'))
-#' markmap(input_txt, widget_options = markmapOption(color = 'category20b', linkShape = 'bracket'))
-#' markmap(input_txt, widget_options = markmapOption(color = 'category10', linkShape = 'diagonal', renderer = 'basic'))
-#' markmap(input_txt, widget_options = markmapOption(nodeHeight = 30, nodeWidth = 100, spacingHorizontal = 60))
+#' @return A list of settings for mind map widget.
 markmapOption <- function(preset = NULL,
                           nodeHeight = 20,
                           nodeWidth = 180,
